# github-experiments


## About the project

This repository is to experiment/test github and github CI/CD features
new
Try colab link
Intro
[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/mert-kurttutan/torchview/blob/main/docs/example_introduction.ipynb)
